Class: Aws::MarketplaceEntitlementService::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MarketplaceEntitlementService::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-marketplaceentitlementservice/client.rb
Overview
An API client for MarketplaceEntitlementService. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MarketplaceEntitlementService::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_entitlements(params = {}) ⇒ Types::GetEntitlementsResult
GetEntitlements retrieves entitlement values for a given product.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
598 599 600 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 598 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
601 602 603 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 601 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 571 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MarketplaceEntitlementService') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-marketplaceentitlementservice' context[:gem_version] = '1.84.0' Seahorse::Client::Request.new(handlers, context) end |
#get_entitlements(params = {}) ⇒ Types::GetEntitlementsResult
GetEntitlements retrieves entitlement values for a given product. The results can be filtered based on customer identifier, AWS account ID, license ARN, or product dimensions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
562 563 564 565 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 562 def get_entitlements(params = {}, = {}) req = build_request(:get_entitlements, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
591 592 593 |
# File 'lib/aws-sdk-marketplaceentitlementservice/client.rb', line 591 def waiter_names [] end |