Class: Aws::MarketplaceEntitlementService::Types::GetEntitlementsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplaceentitlementservice/types.rb

Overview

The GetEntitlementsRequest contains parameters for the GetEntitlements operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterHash<String,Array<String>>

Filter is used to return entitlements for a specific customer or for a specific dimension. Filters are described as keys mapped to a lists of values. Filtered requests are unioned for each value in the value list, and then intersected for each filter key.

CustomerIdentifier and CustomerAWSAccountId are mutually exclusive parameters. You must use one or the other, but not both in the same request.

If you're migrating an existing integration, use Account Feeds to map CustomerIdentifier to CustomerAWSAccountId, and Agreements Feeds to map CustomerAWSAccountId and LicenseArn.

Returns:

  • (Hash<String,Array<String>>)


156
157
158
159
160
161
162
163
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 156

class GetEntitlementsRequest < Struct.new(
  :product_code,
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to retrieve from the GetEntitlements operation. For pagination, use the NextToken field in subsequent calls to GetEntitlements.

Returns:

  • (Integer)


156
157
158
159
160
161
162
163
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 156

class GetEntitlementsRequest < Struct.new(
  :product_code,
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For paginated calls to GetEntitlements, pass the NextToken from the previous GetEntitlementsResult.

Returns:

  • (String)


156
157
158
159
160
161
162
163
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 156

class GetEntitlementsRequest < Struct.new(
  :product_code,
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#product_codeString

Product code is used to uniquely identify a product in AWS Marketplace. The product code will be provided by AWS Marketplace when the product listing is created.

Returns:

  • (String)


156
157
158
159
160
161
162
163
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 156

class GetEntitlementsRequest < Struct.new(
  :product_code,
  :filter,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end