Class: Aws::MarketplaceEntitlementService::Types::GetEntitlementsResult

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-marketplaceentitlementservice/types.rb

Overview

The GetEntitlementsRequest contains results from the GetEntitlements operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#entitlementsArray<Types::Entitlement>

The set of entitlements found through the GetEntitlements operation. If the result contains an empty set of entitlements, NextToken might still be present and should be used.



182
183
184
185
186
187
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 182

class GetEntitlementsResult < Struct.new(
  :entitlements,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

For paginated results, use NextToken in subsequent calls to GetEntitlements. If the result contains an empty set of entitlements, NextToken might still be present and should be used.



182
183
184
185
186
187
# File 'lib/aws-sdk-marketplaceentitlementservice/types.rb', line 182

class GetEntitlementsResult < Struct.new(
  :entitlements,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end